from django.urls import path
from django.views.decorators.csrf import csrf_exempt

from django_ses.views import handle_bounce


app_name = 'ses_sns_tracker'

urlpatterns = [
    path('bounce/', csrf_exempt(handle_bounce)),
]



from django.conf import settings


default_app_config = 'ses_sns_tracker.apps.SESSNSTrackerConfig'


if getattr(settings, 'SES_SNS_TRACKER_USE_CRYPTOGRAPHY', True):
    # monkey patch django_ses.utils.verify_bounce_message (to use CryptographyBounceMessageVerifier)
    import django_ses.utils

    from .utils import verify_bounce_message
    django_ses.utils.verify_bounce_message = verify_bounce_message
